@@ -601,7 +601,9 @@ static int http_client_onMessage(swConnection *conn, char *data, uint32_t length
     zval **args[2];
     zval *retval;
 
-    zval *zframe = php_swoole_websocket_unpack(cli->buffer TSRMLS_CC);
+    zval *zframe;
+    SW_MAKE_STD_ZVAL(zframe);
+    php_swoole_websocket_unpack(cli->buffer, zframe TSRMLS_CC);
 
     args[0] = &zobject;
     args[1] = &zframe;
@@ -621,7 +623,7 @@ static int http_client_onMessage(swConnection *conn, char *data, uint32_t length
     {
         sw_zval_ptr_dtor(&retval);
     }
-    sw_zval_free(zframe);
+    sw_zval_ptr_dtor(&zframe);
 
     return SW_OK;
 }
