@@ -42,7 +42,7 @@ static PHP_METHOD(swoole_process, exec);
 
 static void php_swoole_onSignal(int signo);
 
-static uint32_t php_swoole_worker_round_id = 1;
+static uint32_t php_swoole_worker_round_id = 0;
 static zval *signal_callback[SW_SIGNO_MAX];
 static zend_class_entry swoole_process_ce;
 zend_class_entry *swoole_process_class_entry_ptr;
@@ -236,12 +236,16 @@ static PHP_METHOD(swoole_process, __construct)
     swWorker *process = emalloc(sizeof(swWorker));
     bzero(process, sizeof(swWorker));
 
-    process->id = php_swoole_worker_round_id++;
-
+    int base = 1;
+    if (SwooleG.serv && SwooleGS->start)
+    {
+        base = SwooleG.serv->worker_num + SwooleG.task_worker_num + SwooleG.serv->user_worker_num;
+    }
     if (php_swoole_worker_round_id == 0)
     {
-        php_swoole_worker_round_id = 1;
+        php_swoole_worker_round_id = base;
     }
+    process->id = php_swoole_worker_round_id++;
 
     if (redirect_stdin_and_stdout)
     {
@@ -671,6 +675,7 @@ int php_swoole_process_start(swWorker *process, zval *object TSRMLS_DC)
     {
         php_swoole_event_wait();
     }
+    SwooleG.running = 0;
 
     zend_bailout();
     return SW_OK;
@@ -733,7 +738,7 @@ static PHP_METHOD(swoole_process, read)
     int ret = read(process->pipe, buf, buf_size);;
     if (ret < 0)
     {
-        efree(buf); 
+        efree(buf);
         if (errno != EINTR)
         {
             swoole_php_error(E_WARNING, "failed. Error: %s[%d]", strerror(errno), errno);
@@ -900,7 +905,7 @@ static PHP_METHOD(swoole_process, exec)
     char **exec_args = emalloc(sizeof(char*) * (exec_argc + 2));
 
     zval *value = NULL;
-    exec_args[0] = strdup(execfile);
+    exec_args[0] = sw_strdup(execfile);
     int i = 1;
 
     SW_HASHTABLE_FOREACH_START(Z_ARRVAL_P(args), value)
@@ -1005,10 +1010,7 @@ static PHP_METHOD(swoole_process, exit)
 
     close(process->pipe);
 
-    if (SwooleG.main_reactor != NULL)
-    {
-        SwooleG.running = 0;
-    }
+    SwooleG.running = 0;
 
     if (ret_code == 0)
     {
